@@ -39,8 +39,10 @@ type daemonConfig struct {
 	CacheDir string `mapstructure:"cache_dir"`
 	RunDir   string `mapstructure:"run_dir"`
 
-	DconfDir    string `mapstructure:"dconf_dir"`
-	SSSCacheDir string `mapstructure:"sss_cache_dir"`
+	DconfDir     string `mapstructure:"dconf_dir"`
+	SudoersDir   string `mapstructure:"sudoers_dir"`
+	PolicyKitDir string `mapstructure:"policykit_dir"`
+	SSSCacheDir  string `mapstructure:"sss_cache_dir"`
 
 	ServiceTimeout        int    `mapstructure:"service_timeout"`
 	ADServer              string `mapstructure:"ad_server"`
@@ -104,6 +106,8 @@ func New() *App {
 				adsysservice.WithCacheDir(a.config.CacheDir),
 				adsysservice.WithRunDir(a.config.RunDir),
 				adsysservice.WithDconfDir(a.config.DconfDir),
+				adsysservice.WithSudoersDir(a.config.SudoersDir),
+				adsysservice.WithPolicyKitDir(a.config.PolicyKitDir),
 				adsysservice.WithSSSCacheDir(a.config.SSSCacheDir),
 				adsysservice.WithDefaultDomainSuffix(a.config.ADDefaultDomainSuffix),
 			)
@@ -150,6 +154,7 @@ func New() *App {
 
 	// subcommands
 	a.installVersion()
+	a.installRunScripts()
 
 	return &a
 }
@@ -207,3 +212,8 @@ func (a App) RootCmd() cobra.Command {
 func (a *App) WaitReady() {
 	<-a.ready
 }
+
+// SetArgs changes the root command args. Shouldn’t be in general necessary apart for integration tests.
+func (a *App) SetArgs(args []string) {
+	a.rootCmd.SetArgs(args)
+}
