@@ -14,6 +14,7 @@ var (
 
 type PeerCredsInfo = peerCredsInfo
 
+//nolint:revive // Revive doesn’t understand we return an exported type aliases
 func NewTestPeerCredsInfo(uid uint32, pid int32) PeerCredsInfo {
 	return PeerCredsInfo{uid: uid, pid: pid}
 }
@@ -28,7 +29,12 @@ type DbusMock struct {
 func (d *DbusMock) Call(method string, flags dbus.Flags, args ...interface{}) *dbus.Call {
 	var errPolkit error
 
-	d.actionRequested = Action{ID: args[1].(string)}
+	content, ok := args[1].(string)
+	if !ok {
+		panic("Expected string as second argument")
+	}
+
+	d.actionRequested = Action{ID: content}
 
 	if d.WantPolkitError {
 		errPolkit = errors.New("Polkit error")
