@@ -7,11 +7,11 @@ import (
 	log "github.com/ubuntu/adsys/internal/grpc/logstreamer"
 )
 
-// OnError prefixes any error with format/args
+// OnError prefixes any error with format/args.
 func OnError(err *error, format string, args ...interface{}) {
 	if *err != nil {
 		s := fmt.Sprintf(format, args...)
-		*err = fmt.Errorf("%s: %v", s, *err)
+		*err = fmt.Errorf("%s: %w", s, *err)
 	}
 }
 
